@@ -3,6 +3,7 @@ For support please email 706.goastro.com
 """
 
 from .api import run_call,set_authentication
+from .middleware.webhook import verify
 from .batches import *
 from .batches.current import *
 from .batches.transactions import *
@@ -31,8 +32,10 @@ from .paymentengine.payrequests import *
 from .paymentengine.devices.settings import *
 from .paymentengine.devices.terminal_config import *
 from .paymentengine.devices.kick import *
+from .paymentengine.payrequests.confirm import *
 from .products import *
 from .products.categories import *
+from .publickey import *
 from .tokens import *
 from .transactions import *
 from .transactions.send import *
