@@ -53,4 +53,4 @@ def get(data={}):
 	if 'closedge' in data:
 		params['closedge']=data['closedge']
 
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
