@@ -24,4 +24,4 @@ def get(data={}):
 		params['return_bin']=data['return_bin']
 
 	path='/batches/current/transactions'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
