@@ -25,4 +25,4 @@ def get(data={}):
 		raise Exception('batch_key required for batches.transactions.get()')
 
 	path='/batches/' + data['batch_key'] + '/transactions'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
