@@ -22,4 +22,4 @@ def delete(data={}):
 
 	path='/customers/' + data['custkey'] + '/billing_schedules/' + data['billing_schedule_key'] + '/billing_schedule_rules/bulk'
 	data_list = data['Keys']
-	return run_call('delete',path,data,params)
+	return run_call('delete','json',path,data_list,params)
