@@ -16,4 +16,4 @@ def delete(data={}):
 	params={}
 	path='/customers/bulk'
 	data_list = data['Keys']
-	return run_call('delete',path,data,params)
+	return run_call('delete','json',path,data_list,params)
