@@ -18,4 +18,4 @@ def get(data={}):
 		raise Exception('custkey required for customers.transactions.get()')
 
 	path='/customers/' + data['custkey'] + '/transactions'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
