@@ -23,4 +23,4 @@ def get(data={}):
 		raise Exception('invoice_key required for invoices.payments.get()')
 
 	path='/invoices/' + data['invoice_key'] + '/payments'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
