@@ -18,4 +18,4 @@ def post(data={}):
 		raise Exception('devicekey required for paymentengine.devices.kick.post()')
 
 	path='/paymentengine/devices/' + data['devicekey'] + '/kick'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
