@@ -18,7 +18,7 @@ def get(data={}):
 		raise Exception('devicekey required for paymentengine.devices.terminal-config.get()')
 
 	path='/paymentengine/devices/' + data['devicekey'] + '/terminal-config'
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
 
 def put(data={}):
 	"""Calls /paymentengine/devices/{devicekey}/terminal-config
@@ -37,4 +37,4 @@ def put(data={}):
 		raise Exception('devicekey required for paymentengine.devices.terminal-config.put()')
 
 	path='/paymentengine/devices/' + data['devicekey'] + '/terminal-config'
-	return run_call('put',path,data,params)
+	return run_call('put','json',path,data,params)
