@@ -14,7 +14,7 @@ def post(data={}):
 	"""
 	params={}
 	path='/paymentengine/payrequests'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
 
 def get(data={}):
 	"""Calls /paymentengine/payrequests/{requestkey}
@@ -32,7 +32,7 @@ def get(data={}):
 		raise Exception('requestkey required for paymentengine.payrequests.get()')
 
 	path='/paymentengine/payrequests'+ '/' + data['requestkey']
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
 
 def delete(data={}):
 	"""Calls /paymentengine/payrequests/{requestkey}
@@ -50,4 +50,4 @@ def delete(data={}):
 		raise Exception('requestkey required for paymentengine.payrequests.delete()')
 
 	path='/paymentengine/payrequests'+ '/' + data['requestkey']
-	return run_call('delete',path,data,params)
+	return run_call('delete','json',path,data,params)
