@@ -14,7 +14,7 @@ def post(data={}):
 	"""
 	params={}
 	path='/tokens'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
 
 def get(data={}):
 	"""Calls /tokens/{cardref}
@@ -32,4 +32,4 @@ def get(data={}):
 		raise Exception('cardref required for tokens.get()')
 
 	path='/tokens'+ '/' + data['cardref']
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
