@@ -35,7 +35,7 @@ def get(data={}):
 	if 'filters' in data:
 		params['filters']=data['filters']
 
-	return run_call('get',path,data,params)
+	return run_call('get','json',path,data,params)
 
 def post(data={}):
 	"""Calls /transactions
@@ -49,4 +49,4 @@ def post(data={}):
 	"""
 	params={}
 	path='/transactions'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
