@@ -19,4 +19,4 @@ def post(data={}):
 		raise Exception('trankey required for transactions.send.post()')
 
 	path='/transactions/' + data['trankey'] + '/send'
-	return run_call('post',path,data,params)
+	return run_call('post','json',path,data,params)
